@@ -1,4 +1,4 @@
-import string, re, os, sys, traceback
+import string, re, os, sys, traceback, ctypes
 
 def strmm3( mm ):
   return string.join( map( lambda x: '%s="%s" [correct: "%s"]' % x, mm ), '; ' )
@@ -80,6 +80,7 @@ class checkBase(object):
     self.errorCount = 0
     self.passCount = 0
     self.missingValue = 1.e20
+    self.missingValue = ctypes.c_float(1.00000002004e+20).value
     from file_utils import ncLib
     if ncLib == 'netCDF4':
       import numpy
@@ -350,7 +351,7 @@ class checkGlobalAttributes(checkBase):
     self.checkId = ('003','variable_type')
 
     mipType = vocabs['variable'].getAttr( varName, varGroup, 'type' )
-    thisType = {'real':'float32', 'integer':'int32', 'float':'float32' }.get( mipType, mipType )
+    thisType = {'real':'float32', 'integer':'int32', 'float':'float32', 'double':'float64' }.get( mipType, mipType )
     self.test( mipType == None or varAts[varName]['_type'] == thisType, 'Variable [%s/%s] not of type %s [%s]' % (varName,varGroup,str(thisType),varAts[varName]['_type']) )
 
     self.checkId = ('004','variable_ncattribute_present')
@@ -382,7 +383,10 @@ class checkGlobalAttributes(checkBase):
       if mipType == 'real':
         if varAts[varName].has_key( 'missing_value' ):
            msg = 'Variable [%s] has incorrect attribute missing_value=%s [correct: %s]' % (varName,varAts[varName]['missing_value'],self.missingValue)
-           ok &= self.test( varAts[varName]['missing_value'] == self.missingValue, msg, part=True )
+           ## print varAts[varName]['missing_value'], type(varAts[varName]['missing_value'])
+           ## print self.missingValue, type(self.missingValue)
+### need to use ctypes here when using ncq3 to read files -- appears OK for other libraries.
+           ok &= self.test( ctypes.c_float(varAts[varName]['missing_value']).value == ctypes.c_float(self.missingValue).value, msg, part=True )
         if varAts[varName].has_key( '_FillValue' ):
            msg = 'Variable [%s] has incorrect attribute _FillValue=%s [correct: %s]' % (varName,varAts[varName]['_FillValue'],self.missingValue)
            ok &= self.test( varAts[varName]['_FillValue'] == self.missingValue, msg, part=True )
@@ -538,7 +542,7 @@ class checkStandardDims(checkBase):
 
       ok &= self.test(  da['time'].has_key( 'calendar' ), 'Time: required attribute calendar missing', part=True )
 
-      ok &= self.test( da['time']['_type'] == "float64", 'Time: data type not float64', part=True )
+      ok &= self.test( da['time']['_type'] in ["float64","double"], 'Time: data type not float64 [%s]' % da['time']['_type'], part=True )
        
       if ok:
         self.log_pass()
@@ -886,35 +890,44 @@ class checkByVar(checkBase):
 
   def impt(self,flist):
     ee = {}
+    elist = []
     for f in flist:
       fn = string.split(f, '/' )[-1]
       fnParts = string.split( fn[:-3], '_' )
-      ##if self.cls == 'CORDEX':
-        ##isFixed = fnParts[7] == 'fx'
-        ##group = fnParts[7]
-      ##elif self.cls == 'SPECS':
-        ##isFixed = fnParts[1] == 'fx'
-        ##group = fnParts[1]
+      
+      try:
+        if self.pcfg.freqIndex != None:
+          freq = fnParts[self.pcfg.freqIndex]
+        else:
+          freq = None
 
-      if self.pcfg.freqIndex != None:
-        freq = fnParts[self.pcfg.freqIndex]
-      else:
-        freq = None
+        isFixed = freq == 'fx'
+        group = fnParts[ self.pcfg.groupIndex ]
 
-      isFixed = freq == 'fx'
-      group = fnParts[ self.pcfg.groupIndex ]
-
-      if isFixed:
-        trange = None
-      else:
-        trange = string.split( fnParts[-1], '-' )
-      var = fnParts[0]
-      thisKey = string.join( fnParts[:-1], '.' )
-      if group not in ee.keys():
-        ee[group] = {}
-      if thisKey not in ee[group].keys():
-        ee[group][thisKey] = []
-      ee[group][thisKey].append( (f,fn,group,trange) )
+        if isFixed:
+          trange = None
+        else:
+          trange = string.split( fnParts[-1], '-' )
+        var = fnParts[0]
+        thisKey = string.join( fnParts[:-1], '.' )
+        if group not in ee.keys():
+          ee[group] = {}
+        if thisKey not in ee[group].keys():
+          ee[group][thisKey] = []
+        ee[group][thisKey].append( (f,fn,group,trange) )
+      except:
+        print 'Cannot parse file name: %s' % (f) 
+        elist.append(f)
+## this ee entry is not used, except in bookkeeping check below. 
+## parsing of file name is repeated later, and a error log entry is created at that stage -- this could be improved.
+## in order to improve, need to clarify flow of program: the list here is used to provide preliminary info before log files etc are set up.
+        group = '__error__'
+        thisKey = fn
+        if group not in ee.keys():
+          ee[group] = {}
+        if thisKey not in ee[group].keys():
+          ee[group][thisKey] = []
+        ee[group][thisKey].append( (f,fn,group) )
 
     nn = len(flist)
     n2 = 0
@@ -923,7 +936,12 @@ class checkByVar(checkBase):
         n2 += len( ee[k][k2] )
 
     assert nn==n2, 'some file lost!!!!!!'
-    self.info =  '%s files, %s frequencies' % (nn,len(ee.keys()) )
+    if len(elist) == 0:
+      self.info =  '%s files, %s frequencies' % (nn,len(ee.keys()) )
+    else:
+      self.info =  '%s files, %s frequencies, severe errors in file names: %s' % (nn,len(ee.keys()),len(elist) )
+      for e in elist:
+        self.info += '\n%s' % e
     self.ee = ee
 
   def check(self, recorder=None,calendar='None',norun=False):
